%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Jyvaskylan yliopiston Fysiikan laitoksen LuK-tutkielma (jyflluk.cls)
% Dokumenttiluokka
% Versio 1.5 (06/03/2018)
% 
% Alkuperäinen tekijä:
% Jussi Maunuksela (jussi.o.maunuksela at jyu.fi)
%
% Lisenssi:
% CC BY-NC-SA 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/)
%
% Muutokset:
%
% 2015-11-10 (1.3) - Lisätty: icomma.makropaketti
%                  - Muutettu riviväli: 1.0 -> 1.5
% 2016-01-08 (1.4) - Poistettu kaksoiskirjaimet / disabled ligatures
% 2018-03-06 (1.5) - Lisätty makropaketit: setspace, lipsum
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ProvidesClass{jyflluk}[2017/03/06 versio 1.5 JYFL kandidaatintutkielman dokumenttiluokka]
\NeedsTeXFormat{LaTeX2e}

% ================================================================
% DOKUMENTTILUOKAN MÄÄRITELMÄT:
%
% Dokumentti ladotaan artikkelina (article), jolle on määritelty 
% - peruskirjasimen kooksi 12 pistettä (12 pt)
% - taitto kaksipuoleiselle tulostukselle (twoside) A4-kokoiselle paperille (a4paper) 
% - matemaattisten kaavojen ladonta vasempaan reunaan tasattuina (fleqn)
%   
\LoadClass[12pt,a4paper,fleqn,twoside]{article}

%% Makropaketit:

% Käsikirjoituksessa käytetään utf-8 merkistöä
\RequirePackage[utf8]{inputenc}

% LaTeX käyttää kirjasimen merkkivalikoimana T1-merkistöä täydennettynä 
% Computer Modern-like -kirjasimilla ja microtype -makroilla.  
\RequirePackage[T1]{fontenc} % encoding containing umlaut letters
\RequirePackage{lmodern} % Computer Modern-like fonts with T1 support
\RequirePackage[final]{microtype}
\DisableLigatures[f]{encoding = *, family = *} % no combining f with an adjacent letter

% Desimaalilukujen erottimena käytettävän pilkun eteen tulevan välin 
% oikea mitoitus saadaan icomma-makroilla.
\RequirePackage{icomma}

% Kuvien ja taulukoiden selitteiden ulkoasun muotoilu, jossa vasemman marginaalin ja
% selitetekstin välissä olevan tilan leveys on 10 pistettä. Kuvien ja taulukoiden 
% tunnisteen ladotaan paksunnetulla kirjasimella (bf) ja tunniste, kuten "Kuva 1", 
% erotetaan varsinaisesta selitetekstistä pisteellä, esim. "Kuva 1. Mekaaninen 
% värähtelijä".
\RequirePackage[margin=10pt,labelfont=bf,labelsep=period]{caption}[2013/02/03]

% Dokumentissa on käytössä englannin ja suomen tavutussäännöt, joista suomen
% tavutussäännöt ovat ensisijaisesti käytössä. Englannin tavutus otetaan erillisellä 
% komennolla käyttöön tekstissä.
\RequirePackage[english,finnish]{babel} % Active language: Finnish

% Automaattisesti generoituvan tekstin muuttaminen suomenkieliseksi:
\addto\captionsfinnish{%
  \renewcommand{\refname}{Lähteet} % Lähdeluettelon otsikko
  \renewcommand{\figurename}{Kuvio} % Kuvatekstin otsikko
}

% Dokumentin paperin kooksi on määritelty A4-kokoinen paperi, vasemman ja oikean 
% marginaalin leveydeksi 25 mm sekä ala- ylämarginaalin leveydeksi 35 mm. Tutkielman 
% sidontaa varten varataan sivun reunasta 10 mm levyinen alue.
\RequirePackage[a4paper,left=25mm,right=25mm,top=35mm,bottom=35mm,bindingoffset=10mm]{geometry}
\setlength{\headheight}{15pt}

% Tekstin riviväliksi on asetettu 1,5 kertaa peruskirjasimen koko:
\linespread{1.3} % For one-and-a-half spacing you have to use 1.3. 

% Sivun ylä- ja alatunnisteet jäävät pois tutkielman ensimmäiseltä sivulta (kansilehdeltä) ja tämän jälkeen sivunumero tulostetaan ylätunnisteeseenmäärittelyssä 
\RequirePackage{fancyhdr}
\fancypagestyle{firstpage}{%
  \fancyhf{}% clear all six fields
  \renewcommand{\headrulewidth}{0pt} %
  \renewcommand{\footrulewidth}{0pt} %
}
\fancypagestyle{followingpage}{%
  \fancyhf{}% clear all six fields
  \fancyhead[LE,RO]{\thepage}%
  \renewcommand{\headrulewidth}{0pt}%
  \renewcommand{\footrulewidth}{0pt}%
}
\pagestyle{followingpage}
\AtBeginDocument{\thispagestyle{firstpage}}

% Lukujen otsikoiden muotoilu
\RequirePackage[noindentafter,nobottomtitles,toctitles]{titlesec}
\newcommand{\sectionbreak}{%
	\cleardoublepage%
	\vspace*{24pt}}

% Lähteiden tulostaminen sisällysluetteloon
\RequirePackage[nottoc]{tocbibind}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% GRAPHICX --- Grafiikan lisääminen dokumenttiin. Oletuksen dokumentin tulostaminen pdf-muotoon
%
\RequirePackage{graphicx}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% HYPERREF --- Hyperlinkkien ladonta tekstin sekaan. 
%
\RequirePackage[final]{hyperref}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% LASTPAGE --- Dokumentin viimeiseen sivuun viittaaminen. 
%
\RequirePackage{lastpage}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% BOOKTABS --- Taulukoiden piirtäminen käyttäen viivoja, joiden ympärille jää sopivasti tilaa.
%
\RequirePackage{booktabs}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% DATETIME --- Päiväyksen muotoilu
%
\RequirePackage{datetime}
\renewcommand{\dateseparator}{.}
\setdefaultdate{\dmyyyydate}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% URL --- URL-osoitteiden ladonta
%
\RequirePackage{url}

\RequirePackage{setspace}

\RequirePackage{lipsum}

% xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
% JYFLTITLE --- Kansilehden ladonta
%
\RequirePackage{jyflTitle}






